@@ -34,7 +34,7 @@ use strict;
 
 use Carp qw(croak);
 
-our $VERSION = "0.001";
+our $VERSION = "0.002";
 
 =head1 CONSTRUCTOR
 
@@ -69,7 +69,7 @@ be instantiated instead.
 
 =cut
 
-sub new($@) {
+sub new {
 	my $class = shift;
 	return bless(\@_, $class);
 }
@@ -98,19 +98,19 @@ increasing x.
 
 =cut
 
-sub expand($$) {
+sub _expand {
 	my($self, $n) = @_;
 	my $exp = $self->[$n]->expand;
 	splice @$self, $n, 1, @$exp;
 	return @$exp - 1;
 }
 
-sub nhood($$$$) {
+sub _nhood {
 	my($self, $x_method, $x, $n) = @_;
 	START:
 	if(@$self < 2) {
 		while(@$self == 1 && $self->[0]->role eq "SOURCE") {
-			$self->expand(0);
+			$self->_expand(0);
 		}
 		croak "no useful data" if @$self < 2;
 	}
@@ -129,23 +129,23 @@ sub nhood($$$$) {
 	if($min == 0 && $x < $self->[$min]->$x_method) {
 		croak "data does not extend to $x_method=$x"
 			unless $self->[0]->role eq "SOURCE";
-		$max += $self->expand(0);
+		$max += $self->_expand(0);
 		goto START if $min == $max;
 		goto BINSEARCH;
 	} elsif($max == @$self-1 && $x > $self->[$max]->$x_method) {
 		croak "data does not extend to $x_method=$x"
 			unless $self->[$max]->role eq "SOURCE";
-		$max += $self->expand($max);
+		$max += $self->_expand($max);
 		goto START if $min == $max;
 		goto BINSEARCH;
 	}
 	if($self->[$min]->role eq "SOURCE") {
-		$max += $self->expand($min);
+		$max += $self->_expand($min);
 		goto START if $min == $max;
 		$min-- unless $min == 0;
 		goto BINSEARCH;
 	} elsif($self->[$max]->role eq "SOURCE") {
-		$max += $self->expand($max);
+		$max += $self->_expand($max);
 		goto START if $min == $max;
 		$max++ unless $max == @$self - 1;
 		goto BINSEARCH;
@@ -160,13 +160,13 @@ sub nhood($$$$) {
 				if $min == 0 || $max == @$self - 1;
 			my $expanded;
 			if($self->[$min-1]->role eq "SOURCE") {
-				my $diff = $self->expand($min-1);
+				my $diff = $self->_expand($min-1);
 				$min += $diff;
 				$max += $diff;
 				$expanded = 1;
 			}
 			if($self->[$max+1]->role eq "SOURCE") {
-				$self->expand($max+1);
+				$self->_expand($max+1);
 				$expanded = 1;
 			}
 			last unless $expanded;
@@ -177,14 +177,14 @@ sub nhood($$$$) {
 	return @{$self}[$min..$max];
 }
 
-sub nhood_x($$$) {
+sub nhood_x {
 	my($self, $x, $n) = @_;
-	return $self->nhood("x", $x, $n);
+	return $self->_nhood("x", $x, $n);
 }
 
-sub nhood_y($$$) {
+sub nhood_y {
 	my($self, $y, $n) = @_;
-	return $self->nhood("y", $y, $n);
+	return $self->_nhood("y", $y, $n);
 }
 
 =pod
@@ -219,7 +219,9 @@ Andrew Main (Zefram) <zefram@fysh.org>
 
 =head1 COPYRIGHT
 
-Copyright (C) 2006, 2007 Andrew Main (Zefram) <zefram@fysh.org>
+Copyright (C) 2006, 2007, 2009 Andrew Main (Zefram) <zefram@fysh.org>
+
+=head1 LICENSE
 
 This module is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
